__description__ = "a module that houses object-based wrappers of xgboost based classifiers"
__author__ = "Patrick Godwin (patrick.godwin@ligo.org)"
__doc__ = "\n\n".join([__description__, __author__])

#-------------------------------------------------

from . import sklearn as sklearn_classifiers

from xgboost import XGBClassifier

#--------------------------------
# Extreme Gradient-Boosted Trees
#--------------------------------

class XGBTree(sklearn_classifiers.SupervisedSklearnClassifier):
    """
    A gradient-boosted tree classifier based on xgboost.

    * `XGBoost Intro <https://xgboost.readthedocs.io/en/latest/tutorials/model.html>`_.

    * `XGBoost Hyperparameter Guide <https://xgboost.readthedocs.io/en/latest/parameter.html>`_.

    * `XGBoost API <https://xgboost.readthedocs.io/en/latest/python/python_api.html#module-xgboost.sklearn>`_.

    """
    _flavor = "xgb_tree"

    def _define_classifier(self):
        """
        Defines and returns an extreme gradient-boosted tree model
        """
        return [('classifier', XGBClassifier())]
