__description__ = "a module that tests several aspects of StreamProcessor"
__author__ = "Patrick Godwin (patrick.godwin@ligo.org)"
__doc__ = "\n\n".join([__description__, __author__])

#--------------------------------------------------------------------------

import sys
import pytest

import numpy as np

from ligo import segments as ligo_segments

from idq import io
from idq import utils

#--------------------------------------------------------------------------

#----------------------
#        tests
#----------------------

@pytest.mark.usefixtures('stream_processor')
class TestStreamProcessor(object):
    """
    Tests several aspects of StreamProcessor.
    """

    def test_timestamp(self, kafka_classifierdata_conf):
        stream = self.stream_processor
        umbrella, segs = stream.poll()

        for child in umbrella.children:
            assert child.segs[0] in segs, 'span of data in child is inconsistent with timestamps'

    def test_poll(self, kafka_classifierdata_conf):
        stream = self.stream_processor
        t_start = stream.timestamp
        umbrella, _ = stream.poll()
        while not umbrella.children:
            umbrella, _ = stream.poll()

        for child in umbrella.children:
            assert set(child.channels) == set(kafka_classifierdata_conf['channels']), 'incorrect channels stored in ClassifierData after polling'

    def test_flush(self, kafka_classifierdata_conf, retain=1):
        stream = self.stream_processor
        umbrella, segs = stream.poll()
        while not umbrella.children:
            timestamp = stream.timestamp
            umbrella, segs = stream.poll()

        timestamp = segs[0][0]

        stream.flush(retain=retain)
        assert len(stream._umbrella.children) == retain, 'should only be one ClassifierData object in Umbrella after flushing stream'
        assert stream._umbrella.children[0].start >= timestamp, 'buffer stored in Umbrella should have a start time at least as large as the current timestamp'
        assert stream._buffer.start >= timestamp, 'buffer stored in StreamProcessor should have a start time greater than or equal to timestamp'
